{% load static from staticfiles %}

<link href="{% static 'lazycrud/css/datatables.min.css' %}" rel="stylesheet">
<link href="{% static 'lazycrud/css/dataTables.fontAwesome.css' %}" rel="stylesheet">
