{% load static from staticfiles %}

<script src="{% static 'lazycrud/js/dataTables/datatables.min.js' %}"></script>
<script src="{% static 'lazycrud/js/dataTables/moment.min.js' %}"></script>
<script src="{% static 'lazycrud/js/dataTables/datetime-moment.js' %}"></script>
<script id="object-list-script" src="{% static 'lazycrud/js/object_list.js' %}"></script>
