{% extends view.base_template|default:"base.html" %}
{% load i18n %}

{% block title %}{% trans 'Conferma eliminazione' %}{% endblock %}

{% block content %}

<div class="row">
    <div class="col-lg-12">
        <h2 class="page-header">{% trans 'Sei sicuro?' %}</h2>
    </div> <!-- /.col-lg-12 -->
</div> <!-- /.row -->

<div class="row">
    <div class="col-lg-12">
        <form class="form-horizontal" role="form" method="POST" action="">
            {% csrf_token %}
            <button type="submit" class="btn btn-primary">{% trans 'Elimina' %} {{ object }}</button>
            <button type="button" class="btn btn-default" onclick="window.history.back();">{% trans 'Annulla' %}</button>
        </form>
    </div> <!-- /.col-lg-12 -->
</div> <!-- /.row -->

{% endblock %}
